cmoncrawl.aggregator.index_query.IndexAggregator.get_captured_responses — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.aggregator.index_query.IndexAggregator.get_captured_responses

async static IndexAggregator.get_captured_responses(client: ClientSession, cdx_server: str, domain: str, max_retry: int, sleep_step: int, page: int, since: datetime = datetime.datetime(1, 1, 1, 0, 0), to: datetime = datetime.datetime(9999, 12, 31, 23, 59, 59, 999999))